Test check/uncheck of toggle-buttons
"toggle buttons" == check-boxes and radio-buttons
open | ../tests/html/test_check_uncheck.html |
check initial state
verifyChecked | base-spud |
verifyNotChecked | base-rice |
verifyChecked | option-cheese |
verifyNotChecked | option-onions |
okay, now start pushing buttons
check | base-rice |
verifyNotChecked | base-spud |
verifyChecked | base-rice |
uncheck | option-cheese |
verifyNotChecked | option-cheese |
check | option-onions |
verifyChecked | option-onions |
address elements by name+value
verifyNotChecked | option-chilli |
check | option chilli |
verifyChecked | option-chilli |
uncheck | option index=3 |
verifyNotChecked | option-chilli |